'use strict';

var path = require('path');
var svelte = require('svelte');
var rollupPluginutils = require('rollup-pluginutils');

function svelte$1 ( options ) {
	if ( options === void 0 ) options = {};

	var filter = rollupPluginutils.createFilter( options.include, options.exclude );

	var extensions = options.extensions || [ '.html', '.svelte' ];

	return {
		name: 'svelte',

		transform: function transform ( code, id ) {
			if ( !filter( id ) ) { return null; }
			if ( !~extensions.indexOf( path.extname( id ) ) ) { return null; }

			var name = path.basename( id ).replace( path.extname( id ), '' );
			name = "" + (name[0].toUpperCase()) + (name.slice( 1 ));

			return svelte.compile( code, {
				name: name,
				filename: id,
				css: options.css,
				generate: options.generate,
				format: 'es',

				onerror: function onerror ( err ) {
					var message = ( err.loc ? ("(" + (err.loc.line) + ":" + (err.loc.column) + ") ") : '' ) + err.message;
					if ( err.frame ) { message += "\n" + (err.frame); }

					var err2 = new Error( message );
					err2.stack = err.stack;

					throw err2;
				}
			});
		}
	};
}

module.exports = svelte$1;
